import { Card, FSRSParameters, SchedulingCards, RawCardData } from "./types";
export declare class FSRS {
    private parameters;
    constructor(parameters?: Partial<FSRSParameters>);
    /**
     * Create a new card
     */
    createEmptyCard(now?: Date): Card;
    schedule(card: Card, now?: Date): SchedulingCards;
    /**
     * Schedule a card from raw data
     * Combines validation and scheduling in one operation
     * @param rawData - The raw card data
     * @param now - Current time (optional)
     * @returns Scheduling cards for all ratings
     * @throws Error if validation fails
     */
    scheduleRawCard(rawData: RawCardData, now?: Date): SchedulingCards;
    /**
     * Converts and validates raw card data from database/API
     * @param rawData - The raw card data
     * @returns A validated Card object
     * @throws Error if validation fails
     */
    convertRawCard(rawData: RawCardData): Card;
    /**
     * Batch convert and validate multiple raw cards
     * @param rawDataArray - Array of raw card data
     * @returns Object with valid cards and errors
     */
    convertRawCardBatch(rawDataArray: RawCardData[]): {
        valid: Card[];
        errors: Array<{
            index: number;
            error: string;
            data: RawCardData;
        }>;
    };
    private buildSchedulingCards;
    private scheduleCard;
    private buildReviewLog;
    private getRatingKey;
    private initStability;
    private initDifficulty;
    private nextDifficulty;
    private nextStability;
    private nextInterval;
    private retrievability;
    private meanReversion;
    private factor;
    private decay;
    private addDays;
    getRetrievability(card: Card, now?: Date): number;
    updateParameters(newParameters: Partial<FSRSParameters>): void;
    getParameters(): FSRSParameters;
}
//# sourceMappingURL=fsrs.d.ts.map